﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using SolidBrush = MindFusion.Drawing.SolidBrush;

namespace PieChartLabels
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			var values = new List<double> { 23, 54, 17, 9 };
			pieChart1.Series = new CustomPieSeries(
				values,				
				new List<string>()
				{
					" <1 month", " <=3 months", " <=6 months", " >6 months"
				}
			);

			pieChart1.LegendRenderer.ShowSeriesElements = true;
			pieChart1.LegendRenderer.ElementLabelKind = LabelKinds.ZAxisLabel;
			pieChart1.LegendRenderer.Title = "Duration";
			pieChart1.LegendRenderer.Background = new SolidBrush(Color.Transparent);
			pieChart1.LegendRenderer.BorderStroke = new SolidBrush(Color.Transparent);
			pieChart1.Theme.DataLabelsFontSize = 10;
			pieChart1.Theme.HighlightStroke = new SolidBrush(Color.FromArgb(237, 175, 120));
			pieChart1.Theme.HighlightStrokeThickness = 4;


			pieChart1.Plot.SeriesStyle = new PerElementSeriesStyle()
			{
				Fills = new List<List<MindFusion.Drawing.Brush>>()
				{
					new List<MindFusion.Drawing.Brush>()
					{
						new SolidBrush(Color.FromArgb(158, 212, 224)),
						new SolidBrush(Color.FromArgb(187, 236, 247)),
						new SolidBrush(Color.FromArgb(212, 204, 196)),
						new SolidBrush(Color.FromArgb(245, 210, 179))
					}
				},

				Strokes = new List<List<MindFusion.Drawing.Brush>>()
				{
					new List<MindFusion.Drawing.Brush>()
					{
						new SolidBrush(Color.White)
						
					}
				},
				StrokeThicknesses = new List<List<double>>()
				{
					new List<double>()
					{
						3.0

					}
				}
			};

			pieChart1.Title = "Internship Statistics";
			pieChart1.LicenseKey = "put your license key here to disable trial label";
		}
	}

	public class CustomPieSeries : Series
	{
		public CustomPieSeries(IList<double> data, IList<string> legendLabels )
		{
			values = data;		
			_legendLabels = legendLabels;

			//sum up all pie data
			total = 0.0;
			for (int i = 0; i < data.Count; i++)
				total += data[i];
		}

		public double GetValue(int index, int dimension)
		{			
				return values[index];
		
		}

		public string GetLabel(int index, LabelKinds kind)
		{
			double percent = (values[index] / total) * 100;
			if (kind == LabelKinds.InnerLabel)
				return percent.ToString("F2") + "%\n" + values[index].ToString();
			if (kind == LabelKinds.ToolTip)
				return "Number of interns: " + values[index].ToString("F0") + 
					"\nPercent of total: " + percent.ToString("F2") + "%";

			if (kind == LabelKinds.ZAxisLabel)
				return _legendLabels[index].ToString();

			return null;
		}

		public bool IsSorted(int dimension)
		{
			return false;
		}

		public bool IsEmphasized(int index)
		{
			return false;
		}

		public int Size
		{
			get { return values.Count; }
		}

		public int Dimensions
		{
			get { return 1; }
		}

		public string Title
		{
			get { return ""; }
		}

		public LabelKinds SupportedLabels
		{
			get { return LabelKinds.InnerLabel | LabelKinds.ToolTip | LabelKinds.ZAxisLabel; }
		}

		public event EventHandler DataChanged;

		IList<double> values;	
		IList<string> _legendLabels;
		double total = 0L;

	}
}
